@@ -734,7 +734,7 @@ def create_app() -> FastAPI:
     @app.get("/app/{full_path:path}")
     async def serve_frontend_app(full_path: str):
         """Serve the built Vue.js frontend application"""
-        static_dir = os.path.join(os.path.dirname(__file__), "../../../frontend_dist")
+        static_dir = os.getenv("II_SLIDE_STATIC_DIR")
         file_path = os.path.join(static_dir, full_path)
 
         # If file exists, serve it
